==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag…" : "Tag wählen",
    "Tagged files" : "Getaggte Dateien",
    "Select tags to filter by" : "Wählen Sie Tags nach denen gefiltert werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Tags nach denen gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben den System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hast den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "You added system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "You removed system tag %2$s from %1$s" : "Sie haben den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei wurden geändert",
    "Collaborative tags" : "Gemeinsame Tags",
    "Create and edit collaborative tags. These tags affect all users." : "Erstellen und bearbeiten Sie Zusammenarbeits-Tags. Diese Tags betreffen alle Benutzer.",
    "Select tag …" : "Tag wählen ...",
    "Name" : "Name",
    "Delete" : "Löschen",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/de_DE.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Tags",
    "Update" : "Aktualisieren",
    "Create" : "Erstellen",
    "Select tag…" : "Tag wählen",
    "Tagged files" : "Mit Tags versehene Dateien",
    "Select tags to filter by" : "Wählen Sie Tags nach denen gefiltert werden soll",
    "No tags found" : "Keine Tags gefunden",
    "Please select tags to filter by" : "Bitte wählen Sie Tags nach denen gefiltert werden sollen",
    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
    "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
    "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
    "%1$s added system tag %2$s" : "%1$s hat den System-Tag %2$s hinzugefügt",
    "{actor} added system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} hinzugefügt",
    "Removed system tag %1$s" : "System-Tag %1$s entfernt",
    "Removed system tag {systemtag}" : "System-Tag {systemtag} entfernt",
    "%1$s removed system tag %2$s" : "%1$s hat den System-Tag %2$s entfernt",
    "{actor} removed system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} entfernt",
    "You created system tag %1$s" : "Sie haben den System-Tag %1$s erstellt",
    "You created system tag {systemtag}" : "Sie haben den System-Tag {systemtag} erstellt",
    "%1$s created system tag %2$s" : "%1$s hat den System-Tag %2$s erstellt",
    "{actor} created system tag {systemtag}" : "{actor} hat den System-Tag {systemtag} erstellt",
    "You deleted system tag %1$s" : "Sie haben den System-Tag %1$s gelöscht",
    "You deleted system tag {systemtag}" : "Sie haben den System-Tag {systemtag} gelöscht",
    "%1$s deleted system tag %2$s" : "%1$s hat System-Tag %2$s gelöscht",
    "{actor} deleted system tag {systemtag}" : "{actor} hast den System-Tag {systemtag} gelöscht",
    "You updated system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s aktualisiert",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sie haben den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hat System-Tag von %3$s zu %2$s aktualisiert",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} hast den System-Tag {oldsystemtag} zu {newsystemtag} aktualisiert",
    "You added system tag %2$s to %1$s" : "Sie haben den System-Tag %2$s zu %1$s hinzugefügt",
    "You added system tag {systemtag} to {file}" : "Sie haben den System-Tag {systemtag} zu {file} hinzugefügt",
    "%1$s added system tag %3$s to %2$s" : "%1$s hat System-Tag %3$s zu %2$s hinzugefügt",
    "{actor} added system tag {systemtag} to {file}" : "{actor} hat den System-Tag {systemtag} zu {file} hinzugefügt",
    "You removed system tag %2$s from %1$s" : "Sie haben den System-Tag %2$s von %1$s entfernt",
    "You removed system tag {systemtag} from {file}" : "Sie haben den System-Tag {systemtag} von {file} entfernt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hat System-Tag %3$s von %2$s entfernt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hat den System-Tag {systemtag} von {file} entfernt",
    "%s (restricted)" : "%s (eingeschränkt)",
    "%s (invisible)" : "%s (unsichtbar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System-Tags</strong> für eine Datei wurden geändert",
    "Collaborative tags" : "Gemeinsame Tags",
    "Create and edit collaborative tags. These tags affect all users." : "Erstellen und bearbeiten Sie gemeinsamen Tags. Diese Tags betreffen alle Benutzer.",
    "Select tag …" : "Tag wählen …",
    "Name" : "Name",
    "Delete" : "Löschen",
    "Public" : "Öffentlich",
    "Restricted" : "Eingeschränkt",
    "Invisible" : "Nicht sichtbar",
    "Reset" : "Zurücksetzen",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Size" : "Größe",
    "Modified" : "Geändert"
},
"nplurals=2; plural=(n != 1);");
